@@ -10,12 +10,6 @@ Reference is C99:
   * http://www.open-std.org/JTC1/SC22/WG14/www/docs/n1124.pdf
 
 '''
-try:
-    from builtins import long
-except ImportError:
-    # python3
-    long = int
-
 __docformat__ = 'restructuredtext'
 
 import operator
@@ -31,6 +25,10 @@ from . import preprocessor
 from . import yacc
 
 
+if sys.version_info.major == 3:
+    long = int
+
+
 tokens = (
     'PP_DEFINE', 'PP_DEFINE_NAME', 'PP_DEFINE_MACRO_NAME', 'PP_MACRO_PARAM',
     'PP_STRINGIFY', 'PP_IDENTIFIER_PASTE', 'PP_END_DEFINE',
